==> odata-client-msgraph-beta-0.1.26-sources.jar: odata/msgraph/client/beta/entity/collection/request/TargetedManagedAppConfigurationCollectionRequest.java <==
package odata.msgraph.client.beta.entity.collection.request;

import com.fasterxml.jackson.annotation.JsonIgnore;
import com.github.davidmoten.odata.client.CollectionPageEntityRequest;
import com.github.davidmoten.odata.client.CollectionPageNonEntityRequest;
import com.github.davidmoten.odata.client.ContextPath;
import com.github.davidmoten.odata.client.NameValue;
import com.github.davidmoten.odata.client.annotation.Action;
import com.github.davidmoten.odata.client.internal.Checks;
import com.github.davidmoten.odata.client.internal.ParameterMap;
import com.github.davidmoten.odata.client.internal.TypedObject;

import java.util.List;
import java.util.Map;

import odata.msgraph.client.beta.complex.HasPayloadLinkResultItem;
import odata.msgraph.client.beta.entity.TargetedManagedAppConfiguration;
import odata.msgraph.client.beta.entity.request.ManagedMobileAppRequest;
import odata.msgraph.client.beta.entity.request.TargetedManagedAppConfigurationRequest;
import odata.msgraph.client.beta.entity.request.TargetedManagedAppPolicyAssignmentRequest;
import odata.msgraph.client.beta.schema.SchemaInfo;

public class TargetedManagedAppConfigurationCollectionRequest extends CollectionPageEntityRequest<TargetedManagedAppConfiguration, TargetedManagedAppConfigurationRequest>{

    protected ContextPath contextPath;

    public TargetedManagedAppConfigurationCollectionRequest(ContextPath contextPath) {
        super(contextPath, TargetedManagedAppConfiguration.class, cp -> new TargetedManagedAppConfigurationRequest(cp), SchemaInfo.INSTANCE);
        this.contextPath = contextPath;
    }

    public ManagedMobileAppCollectionRequest apps() {
        return new ManagedMobileAppCollectionRequest(contextPath.addSegment("apps"));
    }

    public ManagedMobileAppRequest apps(String id) {
        return new ManagedMobileAppRequest(contextPath.addSegment("apps").addKeys(new NameValue(id.toString())));
    }


    public TargetedManagedAppPolicyAssignmentCollectionRequest assignments() {
        return new TargetedManagedAppPolicyAssignmentCollectionRequest(contextPath.addSegment("assignments"));
    }

    public TargetedManagedAppPolicyAssignmentRequest assignments(String id) {
        return new TargetedManagedAppPolicyAssignmentRequest(contextPath.addSegment("assignments").addKeys(new NameValue(id.toString())));
    }

    @Action(name = "hasPayloadLinks")
    @JsonIgnore
    public CollectionPageNonEntityRequest<HasPayloadLinkResultItem> hasPayloadLinks(List<String> payloadIds) {
        Map<String, TypedObject> _parameters = ParameterMap
            .put("payloadIds", "Collection(Edm.String)", Checks.checkIsAscii(payloadIds))
            .build();
        return CollectionPageNonEntityRequest.forAction(this.contextPath.addActionOrFunctionSegment("microsoft.graph.hasPayloadLinks"), HasPayloadLinkResultItem.class, _parameters, odata.msgraph.client.beta.schema.SchemaInfo.INSTANCE);
    }

}

==> odata-client-msgraph-beta-0.2.1-sources.jar: odata/msgraph/client/beta/entity/collection/request/TargetedManagedAppConfigurationCollectionRequest.java <==
package odata.msgraph.client.beta.entity.collection.request;

import com.fasterxml.jackson.annotation.JsonIgnore;
import com.github.davidmoten.odata.client.CollectionPageEntityRequest;
import com.github.davidmoten.odata.client.CollectionPageNonEntityRequest;
import com.github.davidmoten.odata.client.ContextPath;
import com.github.davidmoten.odata.client.NameValue;
import com.github.davidmoten.odata.client.annotation.Action;
import com.github.davidmoten.odata.client.internal.Checks;
import com.github.davidmoten.odata.client.internal.ParameterMap;
import com.github.davidmoten.odata.client.internal.TypedObject;

import java.lang.Object;
import java.lang.String;
import java.util.List;
import java.util.Map;
import java.util.Optional;

import odata.msgraph.client.beta.complex.HasPayloadLinkResultItem;
import odata.msgraph.client.beta.entity.TargetedManagedAppConfiguration;
import odata.msgraph.client.beta.entity.request.ManagedMobileAppRequest;
import odata.msgraph.client.beta.entity.request.TargetedManagedAppConfigurationRequest;
import odata.msgraph.client.beta.entity.request.TargetedManagedAppPolicyAssignmentRequest;

public class TargetedManagedAppConfigurationCollectionRequest extends CollectionPageEntityRequest<TargetedManagedAppConfiguration, TargetedManagedAppConfigurationRequest>{

    protected ContextPath contextPath;

    public TargetedManagedAppConfigurationCollectionRequest(ContextPath contextPath, Optional<Object> value) {
        super(contextPath, TargetedManagedAppConfiguration.class, cp -> new TargetedManagedAppConfigurationRequest(cp, Optional.empty()), value);
        this.contextPath = contextPath;
    }

    public ManagedMobileAppRequest apps(String id) {
        return new ManagedMobileAppRequest(contextPath.addSegment("apps").addKeys(new NameValue(id, String.class)), Optional.empty());
    }

    public ManagedMobileAppCollectionRequest apps() {
        return new ManagedMobileAppCollectionRequest(contextPath.addSegment("apps"), Optional.empty());
    }

    public TargetedManagedAppPolicyAssignmentRequest assignments(String id) {
        return new TargetedManagedAppPolicyAssignmentRequest(contextPath.addSegment("assignments").addKeys(new NameValue(id, String.class)), Optional.empty());
    }

    public TargetedManagedAppPolicyAssignmentCollectionRequest assignments() {
        return new TargetedManagedAppPolicyAssignmentCollectionRequest(contextPath.addSegment("assignments"), Optional.empty());
    }

    @Action(name = "hasPayloadLinks")
    @JsonIgnore
    public CollectionPageNonEntityRequest<HasPayloadLinkResultItem> hasPayloadLinks(List<String> payloadIds) {
        Map<String, TypedObject> _parameters = ParameterMap
            .put("payloadIds", "Collection(Edm.String)", Checks.checkIsAscii(payloadIds))
            .build();
        return CollectionPageNonEntityRequest.forAction(this.contextPath.addActionOrFunctionSegment("microsoft.graph.hasPayloadLinks"), HasPayloadLinkResultItem.class, _parameters);
    }

}
